==> ngs-sdk_1.3.0.orig.tar.gz: ngs-1.3.0/ngs-sdk/language/c++/AlignmentIterator.cpp <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#include <ngs/AlignmentIterator.hpp>

namespace ngs
{
    AlignmentIterator :: AlignmentIterator ( AlignmentRef ref )
            throw ()
        : Alignment ( ref )
    {
    }

    AlignmentIterator & AlignmentIterator :: operator = ( const AlignmentIterator & obj )
        throw ( ErrorMsg )
    {
        Alignment :: operator = ( obj );
        return * this;
    }

    AlignmentIterator :: AlignmentIterator ( const AlignmentIterator & obj )
            throw ( ErrorMsg )
        : Alignment ( obj )
    {
    }
    
    AlignmentIterator :: ~ AlignmentIterator ()
        throw ()
    {
    }

} // namespace ngs

==> ngs-sdk_2.10.9.orig.tar.gz: ngs-2.10.9/ngs-sdk/language/c++/AlignmentIterator.cpp <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#include <ngs/AlignmentIterator.hpp>

namespace ngs
{
    AlignmentIterator :: AlignmentIterator ( AlignmentRef ref )
            NGS_NOTHROW ()
        : Alignment ( ref )
    {
    }

    AlignmentIterator & AlignmentIterator :: operator = ( const AlignmentIterator & obj )
        NGS_THROWS ( ErrorMsg )
    {
        Alignment :: operator = ( obj );
        return * this;
    }

    AlignmentIterator :: AlignmentIterator ( const AlignmentIterator & obj )
            NGS_THROWS ( ErrorMsg )
        : Alignment ( obj )
    {
    }

    AlignmentIterator :: ~ AlignmentIterator ()
        NGS_NOTHROW ()
    {
    }

} // namespace ngs
